@@ -15,11 +15,11 @@ class ScpiDevice(object):
 
     def __init__(self, resource: ScpiResource, **kwargs) -> None:
         self.resource = resource
-        self.transport = resource.transport(resource.address)
+        self.transport = resource.transport(resource.address, **kwargs)
         logger.info(f'open [{resource.transport.transport_name}]: {resource.address}')
 
     def is_open(self):
-        return self.transport.is_open
+        return True if self.transport is not None else False
 
     def close(self) -> None:
         if self.transport is not None:
