@@ -1,7 +1,6 @@
 from typing import NamedTuple, Any, Optional, Type, List
 from .scpi_transport_base import ScpiTransports, ScpiTransportBase
 
-
 class ScpiResource(NamedTuple):
     transport: Type[ScpiTransports]
     address: str
@@ -13,19 +12,20 @@ class ScpiResource(NamedTuple):
     info: Optional[Any] = None
 
     @classmethod
-    def discover(cls, **kwargs) -> List['ScpiResource']:
+    def discover(cls, transports: Optional[List[Type[ScpiTransports]]] = None, **kwargs) -> List['ScpiResource']:
         """Find SCPI devices connected to system.
 
         By default lists all available possible SCPI devices. However behaviour can be controlled using
         kwargs supported by the transport classes."""
 
-        transport_classes = ScpiTransportBase.__subclasses__()
+        if transports is None: transports = ScpiTransportBase.__subclasses__()
+
         resources = []
 
-        for transport_class in transport_classes:
+        for transport in transports:
             # filter keyword arguments accepted by transport and call transport's find_devices method
-            args = {k:v for k, v in kwargs.items() if k in transport_class.discover.__code__.co_varnames}
-            resources += transport_class.discover(**args)
+            args = {k:v for k, v in kwargs.items() if k in transport.discover.__code__.co_varnames}
+            resources += transport.discover(**args)
 
         return resources
 
