@@ -8,8 +8,6 @@ from .scpi_transport_base import ScpiTransportBase
 from .scpi_resource import ScpiResource
 from .scpi_exceptions import ScpiTransportException
 
-logger = logging.getLogger(__name__)
-
 
 class ScpiTcpIpTransport(ScpiTransportBase):
     DEFAULT_PORT: int = 5025
@@ -18,7 +16,7 @@ class ScpiTcpIpTransport(ScpiTransportBase):
     transport_info = 'TCP/IP SCPI Transport'
     transport_type = 'TCP/IP'
 
-    socket: socket.socket
+    sock: Optional[socket.socket] = None
 
     @classmethod
     def discover(cls,
@@ -74,10 +72,10 @@ class ScpiTcpIpTransport(ScpiTransportBase):
     def __init__(self, address: str, timeout: float = 5, **kwargs):
         super().__init__(**kwargs)
         self.logger = logging.getLogger(__name__)
-        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
-        self.socket.settimeout(timeout)
-        self.socket.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+        self.sock.settimeout(timeout)
+        self.sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
 
         # Get hostname and port
         addr = urlparse('//' + address)
@@ -86,11 +84,20 @@ class ScpiTcpIpTransport(ScpiTransportBase):
 
         try:
             # Try to connect
-            self.socket.connect((addr.hostname,
-                                 addr.port if addr.port is not None else self.DEFAULT_PORT))
+            self.sock.connect((addr.hostname,
+                               addr.port if addr.port is not None else self.DEFAULT_PORT))
 
             # Make a file interface for easier handling
-            self.io = self.socket.makefile('rwb', buffering=0)
+            self.io = self.sock.makefile('rwb', buffering=0)
             self.io.flush()
         except OSError as e:
             raise ScpiTransportException(e) from e
+
+    def close(self) -> None:
+        # Do regular closing
+        super().close()
+
+        # Close socket as well
+        self.sock.shutdown(socket.SHUT_RDWR)
+        self.sock.close()
+        self.sock = None
